@@ -18,4 +18,5 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 __all__ = ['handlers', 'protocols', 'GopherExceptions', 'gopherentry',
-           'logger', 'fileext', 'pipe']
+           'logger', 'fileext', 'pipe', 'initialization',
+           'initializationTest']
